This function is to try and prevent optimisation to a local optimum and thus checks whether multiple optimisation routines are consistently finding parameter values to within a set tolerance.
.check_optim_conv(optim_params_list, optim_params, tolerance)Boolean
A list, where each element is the output of
stats::optim(). See ?optim for more details.
A list given by the output of stats::optim().
A numeric specifying within which disparity convergence
of parameter estimates and function minimisation is accepted.