Learn R Programming

epiparameter (version 0.4.1)

.clean_string: Standardise the variables input by users

Description

Checks a user has supplied a character string and converts to epiparameter standards: lower-case and whitespace instead of dashes or underscores.

Examples of strings needing to be cleaned are: disease and pathogen names, and epidemiological distributions.

Usage

.clean_string(x)

Value

A character vector of equal length to the input.

Arguments

x

A character string.