Learn R Programming

epiparameter (version 0.4.1)

.convert_params_lnorm: Converts the parameters of the lognormal distribution to summary statistics

Description

Converts the meanlog and sdlog parameters of the lognormal distribution to a number of summary statistics which can be calculated analytically given the lognormal parameters.

Usage

.convert_params_lnorm(...)

Value

A list of eight elements including: mean, median, mode, variance (var), standard deviation (sd), coefficient of variation (cv), skewness, and excess kurtosis (ex_kurtosis).

Arguments

...

<dynamic-dots> Numeric named parameter(s) used to convert to summary statistics. An example is the meanlog and sdlog parameters of the lognormal (lnorm) distribution.