Learn R Programming

epiparameter (version 0.4.1)

.convert_summary_stats_lnorm: Convert summary statistics to parameters of the lognormal distribution

Description

Convert the summary statistics input into the meanlog and sdlog parameters of the lognormal distribution.

Usage

.convert_summary_stats_lnorm(...)

Value

A list of two elements: meanlog and sdlog

Arguments

...

<dynamic-dots> Numeric named summary statistics used to convert to parameter(s). An example is the mean and sd summary statistics for the lognormal (lnorm) distribution.