Learn R Programming

epiparameter (version 0.4.1)

.convert_summary_stats_nbinom: Convert summary statistics to parameters of the negative binomial distribution

Description

Convert summary statistics of the negative binomial distribution the parameters (prob) and (dispersion) of the negative binomial distribution.

Usage

.convert_summary_stats_nbinom(...)

Value

A list of two elements, the probability and dispersion parameters.

Arguments

...

<dynamic-dots> Numeric named summary statistics used to convert to parameter(s). An example is the mean and sd summary statistics for the lognormal (lnorm) distribution.