Learn R Programming

epiparameter (version 0.4.1)

.convert_summary_stats_weibull: Convert summary statistics to parameters of the Weibull distribution

Description

Convert summary statistics input into the shape and scale parameters of the Weibull distribution.

Usage

.convert_summary_stats_weibull(...)

Value

A list of two elements, the shape and scale.

Arguments

...

<dynamic-dots> Numeric named summary statistics used to convert to parameter(s). An example is the mean and sd summary statistics for the lognormal (lnorm) distribution.