Learn R Programming

epiparameter (version 0.4.1)

.get_sym_percentiles: Get the lower and upper percentiles with a preference for symmetrical percentiles

Description

Get the lower and upper percentiles with a preference for symmetrical percentiles

Usage

.get_sym_percentiles(percentiles)

Value

A named numeric vector of two elements with the lower (first element) and upper (second element) percentiles.

Arguments

percentiles

A named vector of percentiles. The names are in the correct format to be converted to their numeric value using as.numeric().