calc_disc_dist_quantile: Calculate the quantiles of a probability distribution based on the vector
of probabilities and time data (e.g. time since infection)
Description
This function can be used in cases where the data on a fitted
distribution is not openly available and the summary statistics of the
distribution are not reported so the data are scraped from the plot and
the quantiles are needed in order use the extract_param() function.
Usage
calc_disc_dist_quantile(prob, days, quantile)
Value
A named vector of quantiles.
Arguments
prob
A numeric vector of probabilities.
days
A numeric vector of days.
quantile
A single numeric or vector of numerics specifying which
quantiles to extract from the distribution.