Options to modify the printing of epiparameter objects.
Currently options are only used to modify the printing of the
<multi_epiparameter> class.
Details
Options are set with options() and retrieved with getOption(). The
epiparameter options are stored as a single named list under the
"epiparameter" option. For example:
Options set before epiparameter is loaded (e.g. in the user's
.Rprofile) are honoured: when the package is attached, any user-supplied
values are merged with the package defaults, and only fields the user has
not specified are filled in with defaults. Options can also be changed
after the package is loaded and take effect immediately.