is_epiparameter_params: Check whether the vector of parameters for the probability distribution
are in the set of possible parameters used in the epiparameter package
Description
Check whether the vector of parameters for the probability distribution
are in the set of possible parameters used in the epiparameter package
A character string specifying the probability
distribution. This should match the R naming convention of probability
distributions (e.g. lognormal is lnorm, negative binomial is nbinom, and
geometric is geom).
prob_distribution_params
A named vector of probability distribution
parameters.
Details
This check for valid parameters is independent of whether the distribution
is truncated or discretised.