Standardise distribution parameter uncertainty
.clean_uncertainty(x, prob_distribution, uncertainty_missing)An uncertainty list for an <epiparameter> object.
An <epiparameter> object.
An S3 class containing the probability
distribution or a character string if the parameters of the probability
distribution are unknown but the name of the distribution is known, or NA
if the distribution name and parameters are unknown. Use
create_prob_distribution() to create prob_distribution.
A boolean logical as to whether uncertainty
is missing (see missing()) from the parent function.