Learn R Programming

epiparameter (version 0.4.1)

epiparameter-package: epiparameter: Classes and Helper Functions for Working with Epidemiological Parameters

Description

logo

Classes and helper functions for loading, extracting, converting, manipulating, plotting and aggregating epidemiological parameters for infectious diseases. Epidemiological parameters extracted from the literature are loaded from the 'epiparameterDB' R package.

Arguments

Author

Maintainer: Joshua W. Lambert joshua.lambert@lshtm.ac.uk (ORCID) [copyright holder]

Authors:

Other contributors:

See Also