Either NULL or a valid R expressions that evaluates to
logicals to subset the list of <epiparameter>, or a function that can be
applied over a list of <epiparameter> objects.
Subsetting (using subset) can be combined with the subsetting done with
the disease and epi_name arguments (and author if specified). If left
as NULL (default) no subsetting is carried out.
The subset argument is similar to subsetting a <data.frame>, but the
difference is that fixed comparisons and not vectorised comparisons are
needed. For example sample_size > 10 is a valid subset expression, but
sample_size == max(sample_size), which would be a valid subset expression
for a <data.frame> does not work. The vectorised expression will often
not error, but will likely return unexpected results. For the
sample_size == max(sample_size) example it will always return TRUE
(except for NAs) as it is a single numeric so will be equal to it's
max value.
The expression should be specified without using the data object name
(e.g. df$var) and instead just var should be supplied. In
other words, this argument uses non-standard evaluation, just as the
subset argument in subset(), and is similar to <data-masking> used
by the dplyr package.