Learn R Programming

epiparameter (version 0.4.1)

get_citation.multi_epiparameter: Get citation from a list of <epiparameter> objects

Description

Extract the citation stored in a list of <epiparameter> objects.

Usage

# S3 method for multi_epiparameter
get_citation(x, ...)

Value

A <bibentry> object containing multiple references. The length of output <bibentry> is equal to the length of the list of <epiparameter>

objects supplied.

Arguments

x

An <epiparameter> object.

...

dots Not used, extra arguments supplied will cause a warning.

Examples

Run this code
# example with list of 
db <- epiparameter_db()
get_citation(db)

Run the code above in your browser using DataLab