powered by
<epiparameter>
Extract the citation stored in a list of <epiparameter> objects.
# S3 method for multi_epiparameter get_citation(x, ...)
A <bibentry> object containing multiple references. The length of output <bibentry> is equal to the length of the list of <epiparameter>
<bibentry>
objects supplied.
An <epiparameter> object.
dots Not used, extra arguments supplied will cause a warning.
# example with list of db <- epiparameter_db() get_citation(db)
Run the code above in your browser using DataLab