get_parameters.epiparameter: Get parameters from an <epiparameter> object
Description
Extract the parameters of the distribution stored in an <epiparameter>
object.
Usage
# S3 method for epiparameter
get_parameters(x, ...)
# S3 method for multi_epiparameter
get_parameters(x, ...)
Value
A named vector of parameters or NA when the <epiparameter>
object is unparameterised.
Arguments
x
An <epiparameter> object.
...
dots Not used, extra arguments supplied will cause a warning.
Details
The <epiparameter> object can be unparameterised in which it lacks
a probability distribution or parameters of a probability distribution,
in this case the get_parameters.epiparameter() method will return NA.